@@ -1,3 +1,5 @@
+# Language choices
+
 LANGUAGES = {
     'bash': 'Command Language',
     'c': 'C Language',
@@ -17,26 +19,23 @@ LANGUAGES = {
     'rb': 'Ruby Language'
 }
 
+# Hint for using the available languages
+
 LANGUAGES_HINT = f'''snippet language (available languages:
 {", ".join([l for l in LANGUAGES.keys()])})
 '''
 
+# Actual service information
+
 PASTEME_SERVICE_URL = 'https://pasteme.pythonanywhere.com'
 
 PASTEME_API_URL = 'https://pasteme.pythonanywhere.com/api/v1/paste/'
 
-CONNECTION_ISSUE_HINT = f'Check your network connection. Make sure the PasteMe service ({PASTEME_SERVICE_URL}) is up and running.'
+# Traceback messages
 
-JSON_TEMPLATE = '''~~ {} ~~
-{}
-'''
+CONNECTION_ISSUE_HINT = 'Check your network connection. Make sure the PasteMe service is up and running.'
 
-EPILOG_DESCRIPTION = '''Use --start (-s) and/or --end (-e) to select a range of lines from the source code to be pasted.
-Author -> Sadra Yahyapour (mailto:lnxpylnxpy@gmail.com)
+# Information
+
+EPILOG_DESCRIPTION = '''Author -> Sadra Yahyapour (mailto:lnxpylnxpy@gmail.com)
 GitHub -> https://github.com/collove/pasteme-cli'''
-
-
-try:
-    from .local_settings import *
-except:
-    pass
\ No newline at end of file
